==> cdk-4.9.10-20030418.tgz: cdk-4.9.10-20030418/include/traverse.h <==
/*
 * $Id: traverse.h,v 1.2 2002/07/10 21:41:50 tom Exp $
 */

#ifndef CDKINCLUDES
#ifndef CDKTRAVERSE_H
#define CDKTRAVERSE_H 1

#include "cdk.h"

#ifndef CDK_H
#define CDKINCLUDES
#include <cdk.h>
#undef CDKINCLUDES
#include <binding.h>
#include <cdkscreen.h>
#include <cdk_objs.h>
#endif

/*
 * Copyright 2002, Thomas Dickey
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgment:
 * 	This product includes software developed by Thomas Dickey
 * 	and contributors.
 * 4. Neither the name of Thomas Dickey, nor the names of contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THOMAS DICKEY AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THOMAS DICKEY OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

extern int  traverseCDKScreen (CDKSCREEN *screen);
extern void exitCancelCDKScreen (CDKSCREEN *screen);
extern void exitCancelCDKScreenOf (CDKOBJS *obj);
extern void exitOKCDKScreen (CDKSCREEN *screen);
extern void exitOKCDKScreenOf (CDKOBJS *obj);
extern void resetCDKScreen (CDKSCREEN *screen);
extern void resetCDKScreenOf (CDKOBJS *obj);

#endif /* CDKTRAVERSE_H */
#endif /* CDKINCLUDES */

==> cdk-4.9.11-20041224.tgz: cdk-4.9.11-20041224/include/traverse.h <==
/*
 * $Id: traverse.h,v 1.6 2004/08/14 12:20:21 tom Exp $
 */

#ifndef CDKINCLUDES
#ifndef CDKTRAVERSE_H
#define CDKTRAVERSE_H 1

#include "cdk.h"

#ifndef CDK_H
#define CDKINCLUDES
#include <cdk.h>
#undef CDKINCLUDES
#include <binding.h>
#include <cdkscreen.h>
#include <cdk_objs.h>
#endif

/*
 * Copyright 1999-2003,2004 Thomas E. Dickey
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgment:
 * 	This product includes software developed by Thomas Dickey
 * 	and contributors.
 * 4. Neither the name of Thomas Dickey, nor the names of contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THOMAS DICKEY AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THOMAS DICKEY OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

extern CDKOBJS *getCDKFocusCurrent (CDKSCREEN * /* screen */);
extern CDKOBJS *setCDKFocusNext (CDKSCREEN * /* screen */);
extern CDKOBJS *setCDKFocusPrevious (CDKSCREEN * /* screen */);
extern int  traverseCDKScreen (CDKSCREEN * /* screen */);
extern void exitCancelCDKScreen (CDKSCREEN * /* screen */);
extern void exitCancelCDKScreenOf (CDKOBJS * /* obj */);
extern void exitOKCDKScreen (CDKSCREEN * /* screen */);
extern void exitOKCDKScreenOf (CDKOBJS * /* obj */);
extern void resetCDKScreen (CDKSCREEN * /* screen */);
extern void resetCDKScreenOf (CDKOBJS * /* obj */);

#endif /* CDKTRAVERSE_H */
#endif /* CDKINCLUDES */
